/* 
 * Copyright (C) 2005 Abel Bennett.
 *
 * This is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the GNU C Library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 * 02111-1307 USA.
 */

/**
 * @file
 * @brief functions that provide a threaded quick sort
 */

/**
 * @author Abel Bennett
 * @date 2002/11/06
 * @version 1.0
 */


#ifndef _PTHREAD_QSORT_H_
#define _PTHREAD_QSORT_H_


#include <stdlib.h>


#ifdef __cplusplus
extern "C" {
#endif

/**
 * @brief sort base in the order specified by the compare function
 * @param base data array
 * @param nel number of elements in data array
 * @param width size of element in data array
 * @param compare compare function for element in data array
 * @param num_threads number of threads to use
 * @warning <ul><li>default thread attributes used</li></ul>
 * @warning <ul><li>cancellation is disabled</li></ul>
 */
extern void pthread_qsort(void * base, const size_t nel, const size_t width,
        int (*compare)(const void *, const void *), const size_t num_threads);

#ifdef __cplusplus
}
#endif

#endif
