/* 
 * Copyright (C) 2005 Abel Bennett.
 *
 * This is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with the GNU C Library; if not, write to the Free
 * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 * 02111-1307 USA.
 */

/**
 * @file
 * @brief various tools for libctf
 */

/**
 * @author Abel Bennett
 * @date 2003/08/18
 * @version 1.0
 */

/**
 * @mainpage libctf
 * This is the documentation for libctf, the c thread foundation library.
 */

#ifndef _PTHREAD_TOOLS_
#define _PTHREAD_TOOLS_


#include <pthread.h>


#ifdef __cplusplus
extern "C" {
#endif


/**
 * @brief ctf major version number
 */
#define PTHREAD_CTF_MAJOR 0

/**
 * @brief ctf minor version number
 */
#define PTHREAD_CTF_MINOR 1

/**
 * @brief ctf micro version number
 */
#define PTHREAD_CTF_MICRO 0


/**
 * @brief returns the number of on-line processors
 * @param number number of processors
 * @return
 * 0 is returned on success<br>
 * non-zero error code is returned on failure
 */
extern int pthread_get_nproc(int * number);

/**
 * @brief returns a string representing the pthread_t
 * @param tid pthread_t ID [input]
 * @param buf pointer to a character array
 * @param len maximum length for buffer
 * @return
 * 0 is returned on success<br>
 * non-zero error code is returned on failure
 */
extern int pthread_get_name(const pthread_t tid, char * buf, const size_t len);

/**
 * @brief returns the version of pthreads library
 * @param buf pointer to a character array
 * @param len maximum length for buffer
 * @return
 * 0 is returned on success<br>
 * non-zero error code is returned on failure
 */
extern int pthread_version(char * buf, const size_t len);

/**
 * @brief returns the version of ctf library
 * @param buf pointer to a character array
 * @param len maximum length for buffer
 * @return
 * 0 is returned on success<br>
 * non-zero error code is returned on failure
 */
extern int pthread_ctf_version(char * buf, const size_t len);

#ifdef __cplusplus
}
#endif

#endif
